==> tecfy_corev2_package-1.1.30.tar.gz: lib/views/general/sync.page.dart <==
part of tecfy_corev2_client_package;

class SyncPage extends StatefulWidget {
  @override
  _SyncPageState createState() => _SyncPageState();
}

class _SyncPageState extends TecfyState<SyncPage> {
  List<dynamic>? _data;
  late ScrollController _scrollController;
  late StreamSubscription<bool> _streamSubscription;
  @override
  initState() {
    _scrollController = ScrollController();

    TecfySyncService.getUnpostedRecords().then((d) {
      _data = d;
      setState(() {});
    });
    _streamSubscription = TecfySyncService.syncWidgetStream.listen((event) {
      if (event && _data != null) return;
      TecfySyncService.getUnpostedRecords().then((d) {
        _data = d;
        setState(() {});
      });
    });
    super.initState();
  }

  @override
  void dispose() {
    _scrollController.dispose();
    _streamSubscription.cancel();
    super.dispose();
  }

  _onTab(item) async {
    if (item['type'] == 'Delete') {
      var result = await AppNavigator.confirmMessage(
          context, 'Are you sure you want to undo Delete?');
      if (result) {
        await TecfySyncService.undoDelete(item['_id']);
        _data = await TecfySyncService.getUnpostedRecords();
        setState(() {});
      }
    } else {
      var result = await AppNavigator.showAppDialog(context,
          (_) => EntityFormPage(item['entity'], data: {'id': item['_id']}));
      if (kDebugMode) print('update result ------- $result');
    }
  }

  _onTabError(item) async {
    if (item['innerError'] != null) {
      AppNavigator.showMessage(context, '', MessageType.error,
          message: item['innerError']);
      // AppNavigator.showAppDialog(context,
      //     (c) => Material(child: Center(child: TecfyText(item['innerError'])
      //     )));
    }
  }

  Widget _getMenu() {
    return PopupMenuButton<String>(
        //onSelected: _controller.choicePopMenuAction,
        onSelected: (cmd) async {
          if (cmd == 'deleteLockedRecords') {
            var result = await AppNavigator.confirmMessage(context,
                'هل انت متاكد من حذف الاضافات والتعديلات للعناصر المقفوله؟');
            if (result) {
              AppNavigator.showLoading(context);
              try {
                if (await TecfySyncService.markeAllLockedItemAsPosted()) {
                  if (kDebugMode) print('done successfully!');
                  _data = await TecfySyncService.getUnpostedRecords();
                  setState(() {});
                } else {
                  print('error');
                }
              } catch (ee) {}
              AppNavigator.resume();
            }
          }
        },
        color: Color.fromRGBO(73, 77, 89, 1),
        itemBuilder: (BuildContext context) => <PopupMenuEntry<String>>[
              PopupMenuItem<String>(
                value: 'deleteLockedRecords',
                textStyle: TextStyle(color: ThemeService.textOnMainColor),
                child: Row(
                  children: [
                    Expanded(child: TecfyText(trans('حذف العناصر المقفوله'))),
                    Icon(
                      Icons.close,
                      color: ThemeService.textOnMainColor,
                      semanticLabel: trans('حذف العناصر المقفوله'),
                    ),
                  ],
                ),
                enabled: true,
              ),
            ]);
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(
      context,
      AppLocale.translate('Settings'),
      'settings',
      isMobile: LayoutService.isMobile(context),
      appBarActions: [TecfySyncService.getSyncIcon(context, false), _getMenu()],
      child: _data == null
          ? Center(child: AppNavigator.getLoadingWidget(100))
          : Scrollbar(
              controller: _scrollController,
              child: SingleChildScrollView(
                controller: _scrollController,
                child: DataTable(
                  showCheckboxColumn: false,
                  sortColumnIndex: 1,
                  sortAscending: false,
                  columns: [
                    DataColumn(
                        label: TecfyText(trans('Entity')), numeric: false),
                    DataColumn(label: TecfyText(trans('Type')), numeric: false),
                    DataColumn(label: TecfyText(trans('Time')), numeric: false),
                    DataColumn(
                        label: TecfyText(trans('Message')), numeric: false)
                  ],
                  rows: _data
                          ?.map<DataRow>((d) => DataRow(
                                cells: [
                                  DataCell(
                                      TecfyText(
                                          EntityService.getEntity(d['entity'])
                                                  ?.nameAr ??
                                              ''),
                                      onTap: () => _onTab(d)),
                                  DataCell(TecfyText(d['type'].toString()),
                                      onTap: () => _onTab(d)),
                                  DataCell(
                                      TecfyText(
                                          DateTime.fromMillisecondsSinceEpoch(
                                                  d['timeStamp'] ?? 0)
                                              .toString()),
                                      onTap: () => _onTab(d)),
                                  DataCell(TecfyText(d['postMessage'] ?? ''),
                                      onTap: () => _onTabError(d)),
                                ],
                              ))
                          .toList() ??
                      [],
                ),
              ),
            ),
    );
  }
}

==> tecfy_corev2_package-1.1.78.tar.gz: lib/views/general/sync.page.dart <==
part of tecfy_corev2_client_package;

class SyncPage extends StatefulWidget {
  @override
  _SyncPageState createState() => _SyncPageState();
}

class _SyncPageState extends TecfyState<SyncPage> {
  List<dynamic>? _data;
  late ScrollController _scrollController;
  late StreamSubscription<bool> _streamSubscription;
  @override
  initState() {
    _scrollController = ScrollController();

    TecfySyncService.getUnpostedRecords().then((d) {
      _data = d;
      setState(() {});
    });
    _streamSubscription = TecfySyncService.syncWidgetStream.listen((event) {
      if (event && _data != null) return;
      TecfySyncService.getUnpostedRecords().then((d) {
        _data = d;
        setState(() {});
      });
    });
    super.initState();
  }

  @override
  void dispose() {
    _scrollController.dispose();
    _streamSubscription.cancel();
    super.dispose();
  }

  _onTab(item) async {
    if (item['type'] == 'Delete') {
      var result = await AppNavigator.confirmMessage(
          context, 'Are you sure you want to undo Delete?');
      if (result) {
        await TecfySyncService.undoDelete(item['_id']);
        _data = await TecfySyncService.getUnpostedRecords();
        setState(() {});
      }
    } else {
      var result = await AppNavigator.showAppDialog(context,
          (_) => EntityFormPage(item['entity'], data: {'_id': item['_id']}));
      if (kDebugMode) print('update result ------- $result');
    }
  }

  _onTabError(item) async {
    if (item['innerError'] != null) {
      AppNavigator.showMessage(context, '', MessageType.error,
          message: item['innerError']);
      // AppNavigator.showAppDialog(context,
      //     (c) => Material(child: Center(child: TecfyText(item['innerError'])
      //     )));
    }
  }

  Widget _getMenu() {
    return PopupMenuButton<String>(
        //onSelected: _controller.choicePopMenuAction,
        onSelected: (cmd) async {
          if (cmd == 'deleteLockedRecords') {
            var result = await AppNavigator.confirmMessage(context,
                'هل انت متاكد من حذف الاضافات والتعديلات للعناصر المقفوله؟');
            if (result) {
              AppNavigator.showLoading(context);
              try {
                if (await TecfySyncService.markeAllLockedItemAsPosted()) {
                  if (kDebugMode) print('done successfully!');
                  _data = await TecfySyncService.getUnpostedRecords();
                  setState(() {});
                } else {
                  print('error');
                }
              } catch (ee) {}
              AppNavigator.resume();
            }
          }
        },
        color: Color.fromRGBO(73, 77, 89, 1),
        itemBuilder: (BuildContext context) => <PopupMenuEntry<String>>[
              PopupMenuItem<String>(
                value: 'deleteLockedRecords',
                textStyle: TextStyle(color: ThemeService.textOnMainColor),
                child: Row(
                  children: [
                    Expanded(child: TecfyText(trans('حذف العناصر المقفوله'))),
                    Icon(
                      Icons.close,
                      color: ThemeService.textOnMainColor,
                      semanticLabel: trans('حذف العناصر المقفوله'),
                    ),
                  ],
                ),
                enabled: true,
              ),
            ]);
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(
      context,
      AppLocale.translate('Settings'),
      'settings',
      isMobile: LayoutService.isMobile(context),
      appBarActions: [TecfySyncService.getSyncIcon(context, false), _getMenu()],
      child: _data == null
          ? Center(child: AppNavigator.getLoadingWidget(100))
          : Scrollbar(
              controller: _scrollController,
              child: SingleChildScrollView(
                controller: _scrollController,
                child: DataTable(
                  showCheckboxColumn: false,
                  sortColumnIndex: 1,
                  sortAscending: false,
                  columns: [
                    DataColumn(
                        label: TecfyText(trans('Entity')), numeric: false),
                    DataColumn(label: TecfyText(trans('Type')), numeric: false),
                    DataColumn(label: TecfyText(trans('Time')), numeric: false),
                    DataColumn(
                        label: TecfyText(trans('Message')), numeric: false)
                  ],
                  rows: _data
                          ?.map<DataRow>((d) => DataRow(
                                cells: [
                                  DataCell(
                                      TecfyText(
                                          EntityService.getEntity(d['entity'])
                                                  ?.nameAr ??
                                              ''),
                                      onTap: () => _onTab(d)),
                                  DataCell(TecfyText(d['type'].toString()),
                                      onTap: () => _onTab(d)),
                                  DataCell(
                                      TecfyText(
                                          DateTime.fromMillisecondsSinceEpoch(
                                                  d['timeStamp'] ?? 0)
                                              .toString()),
                                      onTap: () => _onTab(d)),
                                  DataCell(TecfyText(d['postMessage'] ?? ''),
                                      onTap: () => _onTabError(d)),
                                ],
                              ))
                          .toList() ??
                      [],
                ),
              ),
            ),
    );
  }
}
